pub struct DiagnosticsRecorder(/* private fields */);Expand description
Implementations
Sourceimpl DiagnosticsRecorder
impl DiagnosticsRecorder
Sourcepub fn new(
adapter_info: &RenderAdapterInfo,
device: &RenderDevice,
queue: &RenderQueue,
) -> DiagnosticsRecorder
pub fn new( adapter_info: &RenderAdapterInfo, device: &RenderDevice, queue: &RenderQueue, ) -> DiagnosticsRecorder
Creates the new DiagnosticsRecorder.
Sourcepub fn begin_frame(&mut self)
pub fn begin_frame(&mut self)
Begins recording diagnostics for a new frame.
Sourcepub fn resolve(&mut self, encoder: &mut CommandEncoder)
pub fn resolve(&mut self, encoder: &mut CommandEncoder)
Copies data from QuerySet’s to a Buffer, after which it can be downloaded to CPU.
Should be called before DiagnosticsRecorder::finish_frame.
Sourcepub fn finish_frame(
&mut self,
device: &RenderDevice,
callback: impl FnOnce(RenderDiagnostics) + Send + Sync + 'static,
)
pub fn finish_frame( &mut self, device: &RenderDevice, callback: impl FnOnce(RenderDiagnostics) + Send + Sync + 'static, )
Finishes recording diagnostics for the current frame.
The specified callback will be invoked when diagnostics become available.
Should be called after DiagnosticsRecorder::resolve,
and after all commands buffers have been queued.